@@ -1,6 +1,8 @@
-import unidecode
 import nltk
 
+from i18ngenerator.languages import Language
+
+
 class Transformer:
 
     def __init__(self) -> None:
@@ -8,18 +10,7 @@ class Transformer:
         # Tokenization
         nltk.download("punkt", quiet=True)
 
-    def strip_accents(self, text: str) -> str:
-        """Strip accents in `text` and replace by nearest character
-
-        Args:
-            text (str): The text to strip the accents in
-
-        Returns:
-            str: The accent stripped string
-        """
-        return unidecode.unidecode(text)
-
-    def capitalize(self, text: str) -> str:
+    def capitalize(self, text: str, language: Language) -> str:
         """Capitalize each sentence in `text`
 
         Args:
@@ -28,6 +19,20 @@ class Transformer:
         Returns:
             str: The capitalized sentences of the `text`
         """
+        not_capitalizable_languages = [
+            Language.CHINESE,
+            Language.ARABIC,
+            Language.KOREAN,
+            Language.JAPANESE,
+            Language.HINDI,
+            Language.BENGALI,
+            Language.TAMIL,
+            Language.GUJARATI,
+            Language.THAI,
+            Language.PUNJABI
+        ]
+        if language in not_capitalizable_languages:
+            return text
         sentences = nltk.tokenize.sent_tokenize(text)
         sentences = list(map(lambda s: f"{s[0].upper()}{s[1:]}", sentences))
-        return " ".join(sentences)
\ No newline at end of file
+        return " ".join(sentences)
